@@ -2,21 +2,22 @@
 from __future__ import unicode_literals
 
 MESSAGES = {
-    "LANGUAGE": "polski",
-    "Posts for year %s": "Posty z roku %s",
-    "Archive": "Archiwum",
-    "Posts about %s": "Posty o %s",
-    "Tags": "Tags",
     "Also available in": "Również dostępny w",
+    "Archive": "Archiwum",
+    "LANGUAGE": "polski",
     "More posts about": "Więcej postów o",
-    "Posted": "Opublikowany",
-    "Original site": "Oryginalna strona",
-    "Read in English": "Czytaj po polsku",
-    "Older posts": "Starsze posty",
     "Newer posts": "Nowsze posty",
-    "Previous post": "Poprzedni post",
     "Next post": "Następny post",
-    "Source": "Źródło",
+    "Older posts": "Starsze posty",
+    "Original site": "Oryginalna strona",
+    "Posted": "Opublikowany",
+    "Posts about %s": "Posty o %s",
+    "Posts for year %s": "Posty z roku %s",
+    "Posts for {month} {year}": "Posty z {month} {year}",
+    "Previous post": "Poprzedni post",
+    "Read in English": "Czytaj po polsku",
     "Read more": "Czytaj więcej",
-    "old posts page %d": "stare posty, strona %d"
+    "Source": "Źródło",
+    "Tags": "Tags",
+    "old posts page %d": "stare posty, strona %d",
 }
