@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2012 Roberto Alsina y otros.
+
+# Copyright © 2012-2013 Roberto Alsina and others.
 
 # Permission is hereby granted, free of charge, to any
 # person obtaining a copy of this software and associated
@@ -24,8 +25,11 @@
 # SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 from __future__ import print_function, unicode_literals
-import sys
 from operator import attrgetter
+import os
+import shutil
+import sys
+import warnings
 
 from doit.loader import generate_tasks
 from doit.cmd_base import TaskLoader
@@ -33,12 +37,12 @@ from doit.reporter import ExecutedOnlyReporter
 from doit.doit_cmd import DoitMain
 from doit.cmd_help import Help as DoitHelp
 from doit.cmd_run import Run as DoitRun
+from doit.cmd_clean import Clean as DoitClean
 
+from . import __version__
 from .nikola import Nikola
 from .utils import _reload, sys_decode
 
-VERSION = "5.5"
-
 
 def main(args):
     sys.path.append('')
@@ -46,7 +50,9 @@ def main(args):
         import conf
         _reload(conf)
         config = conf.__dict__
-    except ImportError:
+    except (ImportError, NameError):
+        if os.path.exists('conf.py'):
+            warnings.warn('Error loading conf.py')
         config = {}
 
     site = Nikola(**config)
@@ -62,11 +68,11 @@ class Help(DoitHelp):
         print("Nikola is a tool to create static websites and blogs. For full documentation and more information, please visit http://nikola.ralsina.com.ar\n\n")
         print("Available commands:")
         for cmd in sorted(cmds.values(), key=attrgetter('name')):
-            print("  nikola %s \t\t %s" % (cmd.name, cmd.doc_purpose))
+            print("  nikola %-*s %s" % (20, cmd.name, cmd.doc_purpose))
         print("")
-        print("  nikola help              show help / reference")
-        print("  nikola help <command>    show command usage")
-        print("  nikola help <task-name>  show task usage")
+        print("  nikola help                 show help / reference")
+        print("  nikola help <command>       show command usage")
+        print("  nikola help <task-name>     show task usage")
 
 
 class Build(DoitRun):
@@ -74,6 +80,16 @@ class Build(DoitRun):
     pass
 
 
+class Clean(DoitClean):
+    """A clean that removes cache/"""
+
+    def clean_tasks(self, tasks, dryrun):
+        if not dryrun:
+            if os.path.exists('conf.py'):
+                shutil.rmtree('cache')
+        return super(Clean, self).clean_tasks(tasks, dryrun)
+
+
 class NikolaTaskLoader(TaskLoader):
     """custom task loader to get tasks from Nikola instead of dodo.py file"""
     def __init__(self, nikola):
@@ -91,7 +107,7 @@ class NikolaTaskLoader(TaskLoader):
 
 class DoitNikola(DoitMain):
     # overwite help command
-    DOIT_CMDS = list(DoitMain.DOIT_CMDS) + [Help, Build]
+    DOIT_CMDS = list(DoitMain.DOIT_CMDS) + [Help, Build, Clean]
     TASK_LOADER = NikolaTaskLoader
 
     def __init__(self, nikola):
@@ -123,8 +139,8 @@ class DoitNikola(DoitMain):
                 print("This command needs to run inside an "
                       "existing Nikola site.")
                 return False
-        super(DoitNikola, self).run(cmd_args)
+        return super(DoitNikola, self).run(cmd_args)
 
     @staticmethod
     def print_version():
-        print("Nikola version %s" % VERSION)
+        print("Nikola version " + __version__)
