@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2012 Roberto Alsina y otros.
+
+# Copyright © 2012-2013 Roberto Alsina and others.
 
 # Permission is hereby granted, free of charge, to any
 # person obtaining a copy of this software and associated
@@ -87,6 +88,8 @@ class Nikola(object):
         self.timeline = []
         self.pages = []
         self._scanned = False
+        self._template_system = None
+        self._THEMES = None
         if not config:
             self.configured = False
         else:
@@ -112,6 +115,7 @@ class Nikola(object):
             'ENABLED_EXTRAS': (),
             'EXTRA_HEAD_DATA': '',
             'FAVICONS': {},
+            'FEED_LENGTH': 10,
             'FILE_METADATA_REGEXP': None,
             'FILES_FOLDERS': {'files': ''},
             'FILTERS': {},
@@ -186,12 +190,6 @@ class Nikola(object):
                                                       {self.config['DEFAULT_'
                                                       'LANG']: ''})
 
-        self.THEMES = utils.get_theme_chain(self.config['THEME'])
-
-        self.MESSAGES = utils.load_messages(self.THEMES,
-                                            self.config['TRANSLATIONS'],
-                                            self.config['DEFAULT_LANG'])
-
         # SITE_URL is required, but if the deprecated BLOG_URL
         # is available, use it and warn
         if 'SITE_URL' not in self.config:
@@ -270,89 +268,55 @@ class Nikola(object):
                 plugin_info.plugin_object.set_site(self)
 
         # set global_context for template rendering
-        self.GLOBAL_CONTEXT = {
-        }
+        self._GLOBAL_CONTEXT = {}
 
-        self.GLOBAL_CONTEXT['messages'] = self.MESSAGES
-        self.GLOBAL_CONTEXT['_link'] = self.link
-        self.GLOBAL_CONTEXT['set_locale'] = s_l
-        self.GLOBAL_CONTEXT['rel_link'] = self.rel_link
-        self.GLOBAL_CONTEXT['abs_link'] = self.abs_link
-        self.GLOBAL_CONTEXT['exists'] = self.file_exists
-        self.GLOBAL_CONTEXT['SLUG_TAG_PATH'] = self.config[
+        self._GLOBAL_CONTEXT['_link'] = self.link
+        self._GLOBAL_CONTEXT['set_locale'] = s_l
+        self._GLOBAL_CONTEXT['rel_link'] = self.rel_link
+        self._GLOBAL_CONTEXT['abs_link'] = self.abs_link
+        self._GLOBAL_CONTEXT['exists'] = self.file_exists
+        self._GLOBAL_CONTEXT['SLUG_TAG_PATH'] = self.config[
             'SLUG_TAG_PATH']
 
-        self.GLOBAL_CONTEXT['add_this_buttons'] = self.config[
+        self._GLOBAL_CONTEXT['add_this_buttons'] = self.config[
             'ADD_THIS_BUTTONS']
-        self.GLOBAL_CONTEXT['index_display_post_count'] = self.config[
+        self._GLOBAL_CONTEXT['index_display_post_count'] = self.config[
             'INDEX_DISPLAY_POST_COUNT']
-        self.GLOBAL_CONTEXT['use_bundles'] = self.config['USE_BUNDLES']
-        self.GLOBAL_CONTEXT['use_cdn'] = self.config.get("USE_CDN")
-        self.GLOBAL_CONTEXT['favicons'] = self.config['FAVICONS']
-        self.GLOBAL_CONTEXT['date_format'] = self.config.get(
+        self._GLOBAL_CONTEXT['use_bundles'] = self.config['USE_BUNDLES']
+        self._GLOBAL_CONTEXT['use_cdn'] = self.config.get("USE_CDN")
+        self._GLOBAL_CONTEXT['favicons'] = self.config['FAVICONS']
+        self._GLOBAL_CONTEXT['date_format'] = self.config.get(
             'DATE_FORMAT', '%Y-%m-%d %H:%M')
-        self.GLOBAL_CONTEXT['blog_author'] = self.config.get('BLOG_AUTHOR')
-        self.GLOBAL_CONTEXT['blog_title'] = self.config.get('BLOG_TITLE')
+        self._GLOBAL_CONTEXT['blog_author'] = self.config.get('BLOG_AUTHOR')
+        self._GLOBAL_CONTEXT['blog_title'] = self.config.get('BLOG_TITLE')
 
-        self.GLOBAL_CONTEXT['blog_url'] = self.config.get('SITE_URL', self.config.get('BLOG_URL'))
-        self.GLOBAL_CONTEXT['blog_desc'] = self.config.get('BLOG_DESCRIPTION')
-        self.GLOBAL_CONTEXT['analytics'] = self.config.get('ANALYTICS')
-        self.GLOBAL_CONTEXT['translations'] = self.config.get('TRANSLATIONS')
-        self.GLOBAL_CONTEXT['license'] = self.config.get('LICENSE')
-        self.GLOBAL_CONTEXT['search_form'] = self.config.get('SEARCH_FORM')
-        self.GLOBAL_CONTEXT['disqus_forum'] = self.config.get('DISQUS_FORUM')
-        self.GLOBAL_CONTEXT['mathjax_config'] = self.config.get(
+        self._GLOBAL_CONTEXT['blog_url'] = self.config.get('SITE_URL', self.config.get('BLOG_URL'))
+        self._GLOBAL_CONTEXT['blog_desc'] = self.config.get('BLOG_DESCRIPTION')
+        self._GLOBAL_CONTEXT['analytics'] = self.config.get('ANALYTICS')
+        self._GLOBAL_CONTEXT['translations'] = self.config.get('TRANSLATIONS')
+        self._GLOBAL_CONTEXT['license'] = self.config.get('LICENSE')
+        self._GLOBAL_CONTEXT['search_form'] = self.config.get('SEARCH_FORM')
+        self._GLOBAL_CONTEXT['disqus_forum'] = self.config.get('DISQUS_FORUM')
+        self._GLOBAL_CONTEXT['mathjax_config'] = self.config.get(
             'MATHJAX_CONFIG')
-        self.GLOBAL_CONTEXT['subtheme'] = self.config.get('THEME_REVEAL_CONGIF_SUBTHEME')
-        self.GLOBAL_CONTEXT['transition'] = self.config.get('THEME_REVEAL_CONGIF_TRANSITION')
-        self.GLOBAL_CONTEXT['content_footer'] = self.config.get(
+        self._GLOBAL_CONTEXT['subtheme'] = self.config.get('THEME_REVEAL_CONGIF_SUBTHEME')
+        self._GLOBAL_CONTEXT['transition'] = self.config.get('THEME_REVEAL_CONGIF_TRANSITION')
+        self._GLOBAL_CONTEXT['content_footer'] = self.config.get(
             'CONTENT_FOOTER')
-        self.GLOBAL_CONTEXT['rss_path'] = self.config.get('RSS_PATH')
-        self.GLOBAL_CONTEXT['rss_link'] = self.config.get('RSS_LINK')
+        self._GLOBAL_CONTEXT['rss_path'] = self.config.get('RSS_PATH')
+        self._GLOBAL_CONTEXT['rss_link'] = self.config.get('RSS_LINK')
 
-        self.GLOBAL_CONTEXT['sidebar_links'] = utils.Functionary(list, self.config['DEFAULT_LANG'])
+        self._GLOBAL_CONTEXT['sidebar_links'] = utils.Functionary(list, self.config['DEFAULT_LANG'])
         for k, v in self.config.get('SIDEBAR_LINKS', {}).items():
-            self.GLOBAL_CONTEXT['sidebar_links'][k] = v
+            self._GLOBAL_CONTEXT['sidebar_links'][k] = v
 
-        self.GLOBAL_CONTEXT['twitter_card'] = self.config.get(
+        self._GLOBAL_CONTEXT['twitter_card'] = self.config.get(
             'TWITTER_CARD', {})
-        self.GLOBAL_CONTEXT['hide_sourcelink'] = self.config.get(
+        self._GLOBAL_CONTEXT['hide_sourcelink'] = self.config.get(
             'HIDE_SOURCELINK')
-        self.GLOBAL_CONTEXT['extra_head_data'] = self.config.get('EXTRA_HEAD_DATA')
+        self._GLOBAL_CONTEXT['extra_head_data'] = self.config.get('EXTRA_HEAD_DATA')
 
-        self.GLOBAL_CONTEXT.update(self.config.get('GLOBAL_CONTEXT', {}))
-
-        # check if custom css exist and is not empty
-        custom_css_path = utils.get_asset_path(
-            'assets/css/custom.css',
-            self.THEMES,
-            self.config['FILES_FOLDERS']
-        )
-        if custom_css_path and self.file_exists(custom_css_path, not_empty=True):
-            self.GLOBAL_CONTEXT['has_custom_css'] = True
-        else:
-            self.GLOBAL_CONTEXT['has_custom_css'] = False
-
-        # Load template plugin
-        template_sys_name = utils.get_template_engine(self.THEMES)
-        pi = self.plugin_manager.getPluginByName(
-            template_sys_name, "TemplateSystem")
-        if pi is None:
-            sys.stderr.write("Error loading {0} template system "
-                             "plugin\n".format(template_sys_name))
-            sys.exit(1)
-        self.template_system = pi.plugin_object
-        lookup_dirs = ['templates'] + [os.path.join(utils.get_theme_path(name), "templates")
-                                       for name in self.THEMES]
-        self.template_system.set_directories(lookup_dirs,
-                                             self.config['CACHE_FOLDER'])
-
-        # Check consistency of USE_CDN and the current THEME (Issue #386)
-        if self.config['USE_CDN']:
-            bootstrap_path = utils.get_asset_path(os.path.join(
-                'assets', 'css', 'bootstrap.min.css'), self.THEMES)
-            if bootstrap_path.split(os.sep)[-4] != 'site':
-                warnings.warn('The USE_CDN option may be incompatible with your theme, because it uses a hosted version of bootstrap.')
+        self._GLOBAL_CONTEXT.update(self.config.get('GLOBAL_CONTEXT', {}))
 
         # Load compiler plugins
         self.compilers = {}
@@ -363,9 +327,68 @@ class Nikola(object):
             self.compilers[plugin_info.name] = \
                 plugin_info.plugin_object
 
+    def _get_themes(self):
+        if self._THEMES is None:
+            self._THEMES = utils.get_theme_chain(self.config['THEME'])
+            # Check consistency of USE_CDN and the current THEME (Issue #386)
+            if self.config['USE_CDN']:
+                bootstrap_path = utils.get_asset_path(os.path.join(
+                    'assets', 'css', 'bootstrap.min.css'), self._THEMES)
+                if bootstrap_path.split(os.sep)[-4] != 'site':
+                    warnings.warn('The USE_CDN option may be incompatible with your theme, because it uses a hosted version of bootstrap.')
+
+        return self._THEMES
+
+    THEMES = property(_get_themes)
+
+    def _get_messages(self):
+        return utils.load_messages(self.THEMES,
+                                   self.translations,
+                                   self.default_lang)
+
+    MESSAGES = property(_get_messages)
+
+    def _get_global_context(self):
+        """Initialize some parts of GLOBAL_CONTEXT only when it's queried."""
+        if 'messages' not in self._GLOBAL_CONTEXT:
+            self._GLOBAL_CONTEXT['messages'] = self.MESSAGES
+        if 'has_custom_css' not in self._GLOBAL_CONTEXT:
+            # check if custom css exist and is not empty
+            custom_css_path = utils.get_asset_path(
+                'assets/css/custom.css',
+                self.THEMES,
+                self.config['FILES_FOLDERS']
+            )
+            if custom_css_path and self.file_exists(custom_css_path, not_empty=True):
+                self._GLOBAL_CONTEXT['has_custom_css'] = True
+            else:
+                self._GLOBAL_CONTEXT['has_custom_css'] = False
+
+        return self._GLOBAL_CONTEXT
+
+    GLOBAL_CONTEXT = property(_get_global_context)
+
+    def _get_template_system(self):
+        if self._template_system is None:
+            # Load template plugin
+            template_sys_name = utils.get_template_engine(self.THEMES)
+            pi = self.plugin_manager.getPluginByName(
+                template_sys_name, "TemplateSystem")
+            if pi is None:
+                sys.stderr.write("Error loading {0} template system "
+                                 "plugin\n".format(template_sys_name))
+                sys.exit(1)
+            self._template_system = pi.plugin_object
+            lookup_dirs = ['templates'] + [os.path.join(utils.get_theme_path(name), "templates")
+                                           for name in self.THEMES]
+            self._template_system.set_directories(lookup_dirs,
+                                                  self.config['CACHE_FOLDER'])
+        return self._template_system
+
+    template_system = property(_get_template_system)
+
     def get_compiler(self, source_name):
         """Get the correct compiler for a post from `conf.post_compilers`
-
         To make things easier for users, the mapping in conf.py is
         compiler->[extensions], although this is less convenient for us. The
         majority of this function is reversing that dictionary and error
@@ -673,6 +696,10 @@ class Nikola(object):
                         if orig_name in full_list:
                             continue
                         full_list.append(orig_name)
+                # We eliminate from the list the files inside any .ipynb folder
+                full_list = [p for p in full_list
+                             if not any([x.startswith('.')
+                             for x in p.split(os.sep)])]
 
                 for base_path in full_list:
                     post = Post(
