@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2012 Roberto Alsina y otros.
+# Copyright © 2012-2013 Roberto Alsina and others.
 
 # Permission is hereby granted, free of charge, to any
 # person obtaining a copy of this software and associated
@@ -49,7 +49,7 @@ class ImportMixin(object):
     name = "import_mixin"
     needs_config = False
     doc_usage = "[options] wordpress_export_file"
-    doc_purpose = "Import a wordpress dump."
+    doc_purpose = "import a wordpress dump."
     cmd_options = [
         {
             'name': 'output_folder',
