@@ -1,4 +1,6 @@
-# Copyright (c) 2012 Roberto Alsina y otros.
+# -*- coding: utf-8 -*-
+
+# Copyright © 2012-2013 Roberto Alsina and others.
 
 # Permission is hereby granted, free of charge, to any
 # person obtaining a copy of this software and associated
@@ -34,12 +36,12 @@ from nikola.plugin_categories import Command
 
 
 class CommandBootswatchTheme(Command):
-    """Given a swatch name and a parent theme, creates a custom theme."""
+    """Given a swatch name from bootswatch.com and a parent theme, creates a custom theme."""
 
     name = "bootswatch_theme"
     doc_usage = "[options]"
-    doc_purpose = "Given a swatch name and a parent theme, creates a custom"\
-        " theme."
+    doc_purpose = "given a swatch name from bootswatch.com and a parent theme, creates a custom"\
+        " theme"
     cmd_options = [
         {
             'name': 'name',
