@@ -1,4 +1,6 @@
-# Copyright (c) 2012 Roberto Alsina y otros.
+# -*- coding: utf-8 -*-
+
+# Copyright © 2012-2013 Roberto Alsina and others.
 
 # Permission is hereby granted, free of charge, to any
 # person obtaining a copy of this software and associated
@@ -39,7 +41,7 @@ class Deploy(Command):
     name = "deploy"
 
     doc_usage = ""
-    doc_purpose = "Deploy the site."
+    doc_purpose = "deploy the site"
 
     def _execute(self, command, args):
         # Get last succesful deploy date
