@@ -1,4 +1,6 @@
-# Copyright (c) 2012 Roberto Alsina y otros.
+# -*- coding: utf-8 -*-
+
+# Copyright © 2012-2013 Roberto Alsina and others.
 
 # Permission is hereby granted, free of charge, to any
 # person obtaining a copy of this software and associated
@@ -40,7 +42,7 @@ class CommandInit(Command):
 
     doc_usage = "[--demo] folder"
     needs_config = False
-    doc_purpose = """Create a Nikola site in the specified folder."""
+    doc_purpose = "create a Nikola site in the specified folder"
     cmd_options = [
         {
             'name': 'demo',
@@ -61,7 +63,9 @@ class CommandInit(Command):
 
         'POST_PAGES': """(
     ("posts/*.txt", "posts", "post.tmpl", True),
+    ("posts/*.rst", "posts", "post.tmpl", True),
     ("stories/*.txt", "stories", "story.tmpl", False),
+    ("stories/*.rst", "stories", "story.tmpl", False),
 )""",
 
         'POST_COMPILERS': """{
