@@ -9,8 +9,8 @@ class ImportPluginsTest(unittest.TestCase):
     def test_importing_command_import_wordpress(self):
         import nikola.plugins.command_import_wordpress  # NOQA
 
-    def test_importing_task_sitemap(self):
-        import nikola.plugins.task_sitemap.sitemap_gen  # NOQA
-
     def test_importing_compile_rest(self):
         import nikola.plugins.compile_rest  # NOQA
+
+    def test_importing_plugin_compile_markdown(self):
+        import nikola.plugins.compile_markdown    # NOQA
